==> huaweicloudsdkedgesec-3.1.129-py2.py3-none-any.whl: huaweicloudsdkedgesec/v2/model/time_range_item.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TimeRangeItem:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'st': 'int',
        'end': 'int'
    }

    attribute_map = {
        'st': 'st',
        'end': 'end'
    }

    def __init__(self, st=None, end=None):
        """TimeRangeItem

        The model defined in huaweicloud sdk

        :param st: period每日生效时间区间开始
        :type st: int
        :param end: period每日生效时间区间结束
        :type end: int
        """
        
        

        self._st = None
        self._end = None
        self.discriminator = None

        if st is not None:
            self.st = st
        if end is not None:
            self.end = end

    @property
    def st(self):
        """Gets the st of this TimeRangeItem.

        period每日生效时间区间开始

        :return: The st of this TimeRangeItem.
        :rtype: int
        """
        return self._st

    @st.setter
    def st(self, st):
        """Sets the st of this TimeRangeItem.

        period每日生效时间区间开始

        :param st: The st of this TimeRangeItem.
        :type st: int
        """
        self._st = st

    @property
    def end(self):
        """Gets the end of this TimeRangeItem.

        period每日生效时间区间结束

        :return: The end of this TimeRangeItem.
        :rtype: int
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this TimeRangeItem.

        period每日生效时间区间结束

        :param end: The end of this TimeRangeItem.
        :type end: int
        """
        self._end = end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeRangeItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkedgesec-3.1.150-py2.py3-none-any.whl: huaweicloudsdkedgesec/v2/model/time_range_item.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TimeRangeItem:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'st': 'int',
        'end': 'int'
    }

    attribute_map = {
        'st': 'st',
        'end': 'end'
    }

    def __init__(self, st=None, end=None):
        r"""TimeRangeItem

        The model defined in huaweicloud sdk

        :param st: period每日生效时间区间开始
        :type st: int
        :param end: period每日生效时间区间结束
        :type end: int
        """
        
        

        self._st = None
        self._end = None
        self.discriminator = None

        if st is not None:
            self.st = st
        if end is not None:
            self.end = end

    @property
    def st(self):
        r"""Gets the st of this TimeRangeItem.

        period每日生效时间区间开始

        :return: The st of this TimeRangeItem.
        :rtype: int
        """
        return self._st

    @st.setter
    def st(self, st):
        r"""Sets the st of this TimeRangeItem.

        period每日生效时间区间开始

        :param st: The st of this TimeRangeItem.
        :type st: int
        """
        self._st = st

    @property
    def end(self):
        r"""Gets the end of this TimeRangeItem.

        period每日生效时间区间结束

        :return: The end of this TimeRangeItem.
        :rtype: int
        """
        return self._end

    @end.setter
    def end(self, end):
        r"""Sets the end of this TimeRangeItem.

        period每日生效时间区间结束

        :param end: The end of this TimeRangeItem.
        :type end: int
        """
        self._end = end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeRangeItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
